@@ -1,8 +1,8 @@
 package Net::OAI::ListMetadataFormats;
 
 use strict;
-use base qw( XML::SAX::Base Net::OAI::Base );
-use Carp qw( carp );
+use base qw( XML::SAX::Base );
+use base qw( Net::OAI::Base );
 
 =head1 NAME
 
@@ -21,7 +21,7 @@ Net::OAI::ListMetadataFormats - Results of the ListMetadataFormats OAI-PMH verb.
 sub new {
     my ( $class, %opts ) = @_;
     my $self = bless \%opts, ref( $class ) || $class;
-    $self->{ _insideList } = 0;
+    $self->{ insideList } = 0;
     $self->{ metadataPrefixes } = [];
     $self->{ namespaces } = [];
     $self->{ schemas } = [];
@@ -78,30 +78,24 @@ sub schemas_byprefix {
     return $self->{schemas_byprefix}->{$prefix};
 }
 
-# SAX Handlers
+
+## SAX Handlers
 
 sub start_element {
     my ( $self, $element ) = @_;
-    return $self->SUPER::start_element($element) unless $element->{NamespaceURI} eq Net::OAI::Harvester::XMLNS_OAI;  # should be error?
-
-    if ( $element->{ LocalName } eq 'ListMetadataFormats' ) { 
-	$self->{ _insideList } = 1;
-    } elsif ( $self->{ _insideList } ) {
-    } elsif ( $element->{ LocalName } eq 'OAI-PMH' ) {
+    if ( $element->{ Name } eq 'ListMetadataFormats' ) { 
+	$self->{ insideList } = 1;
     } else {
-        carp "who am I? (".$element->{ LocalName }.")";
 	$self->SUPER::start_element( $element );
     }
-    push( @{ $self->{ tagStack } }, $element->{ LocalName } );
+    push( @{ $self->{ tagStack } }, $element->{ Name } );
 }
 
 sub end_element {
     my ( $self, $element ) = @_;
-    return $self->SUPER::end_element($element) unless $element->{NamespaceURI} eq Net::OAI::Harvester::XMLNS_OAI;  # should be error?
-
-    my $name = $element->{ LocalName };
+    my $name = $element->{ Name };
     if ( $name eq 'ListMetadataFormats' ) {
-	$self->{ _insideList } = 0;
+	$self->{ insideList } = 0;
     } elsif ( $name eq 'metadataFormat' ) {
         my $nspf = delete $self->{ _currpf };
         $self->{ namespaces_byprefix }->{ $nspf } = delete $self->{ _currns };
@@ -118,11 +112,7 @@ sub end_element {
         push( @{ $self->{ namespaces } }, $self->{ metadataNamespace } );
         $self->{ _currns } = $self->{ metadataNamespace };
         $self->{ metadataNamespace } = '';
-    } elsif ( $self->{ _insideList } ) {
-        carp "who am I? ($name)";
-    } elsif ( $element->{ LocalName } eq 'OAI-PMH' ) {
     } else {
-        carp "who am I? ($name)";
 	$self->SUPER::end_element( $element );
     }
     pop( @{ $self->{ tagStack } } );
@@ -130,10 +120,8 @@ sub end_element {
 
 sub characters {
     my ( $self, $characters ) = @_;
-    if ( $self->{ _insideList } ) {
-        $self->{ $self->{ tagStack }[-1] } .= $characters->{ Data }
-    } else {
-        $self->SUPER::characters( $characters )};
+    $self->SUPER::characters( $characters );
+    $self->{ $self->{ tagStack }[-1] } .= $characters->{ Data };
 }
 
 1;
